@@ -1,16 +1,21 @@
 from celery import shared_task
 
+from eveuniverse.core.esitools import is_esi_online
+from eveuniverse.models import EveEntity
+from eveuniverse.tasks import update_unresolved_eve_entities
+
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 
 from . import __title__
-from .helpers import is_esi_online
 from .models import EveWar, SyncedCharacter, SyncManager
-from .providers import esi
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
+DEFAULT_TASK_PRIORITY = 6
+
+
 @shared_task
 def run_regular_sync():
     """update all wars, managers and related characters if needed"""
@@ -18,9 +23,11 @@ def run_regular_sync():
         logger.warning("ESI is not online. aborting")
         return
 
-    update_all_wars.delay()
+    update_all_wars.apply_async(priority=DEFAULT_TASK_PRIORITY)
     for sync_manager_pk in SyncManager.objects.values_list("pk", flat=True):
-        run_manager_sync.delay(sync_manager_pk)
+        run_manager_sync.apply_async(
+            args=[sync_manager_pk], priority=DEFAULT_TASK_PRIORITY
+        )
 
 
 @shared_task
@@ -42,6 +49,8 @@ def run_manager_sync(manager_pk: int, force_sync: bool = False) -> bool:
         logger.debug("Unexpected exception occurred", exc_info=True)
         sync_manager.set_sync_status(sync_manager.Error.UNKNOWN)
         return False
+    else:
+        EveEntity.objects.bulk_update_new_esi()
 
     if not new_version_hash:
         return False
@@ -53,7 +62,10 @@ def run_manager_sync(manager_pk: int, force_sync: bool = False) -> bool:
             version_hash=new_version_hash
         ).values_list("pk", flat=True)
     for character_pk in alts_need_syncing:
-        run_character_sync.delay(sync_char_pk=character_pk, force_sync=force_sync)
+        run_character_sync.apply_async(
+            kwargs={"sync_char_pk": character_pk, "force_sync": force_sync},
+            priority=DEFAULT_TASK_PRIORITY,
+        )
 
     return True
 
@@ -81,15 +93,13 @@ def run_character_sync(sync_char_pk: int, force_sync: bool = False) -> bool:
 
 @shared_task
 def update_all_wars():
-    logger.info("Removing finished wars")
-    EveWar.objects.finished_wars().delete()
-    logger.info("Retrieving wars from ESI")
-    war_ids = esi.client.Wars.get_wars().results()
-    logger.info("Retrieved %s wars from ESI", len(war_ids))
-    for war_id in war_ids:
-        update_war.delay(war_id)
+    relevant_war_ids = EveWar.objects.calc_relevant_war_ids()
+    logger.info("Fetching details for %s wars from ESI", len(relevant_war_ids))
+    for war_id in relevant_war_ids:
+        update_war.apply_async(args=[war_id], priority=DEFAULT_TASK_PRIORITY)
+    update_unresolved_eve_entities.apply_async(priority=DEFAULT_TASK_PRIORITY)
 
 
 @shared_task
 def update_war(war_id: int):
-    EveWar.objects.update_from_esi(war_id)
+    EveWar.objects.update_or_create_from_esi(war_id)
